@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary_conf.h,v 1.19 2008/08/04 19:05:33 fredg Exp $
+//      $Id: rdlibrary_conf.h,v 1.22.8.1 2014/01/09 01:03:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +31,7 @@ class RDLibraryConf
 {
  public:
   enum RecordMode {Manual=0,Vox=1};
+  enum SearchLimit {LimitNo=0,LimitYes=1,LimitPrevious=2};
   RDLibraryConf(const QString &station,unsigned instance);
   QString station() const;
   unsigned instance() const;
@@ -50,8 +51,6 @@ class RDLibraryConf
   void setDefaultFormat(unsigned format) const;
   unsigned defaultChannels() const;
   void setDefaultChannels(unsigned chans) const;
-  unsigned defaultSampleRate() const;
-  void setDefaultSampleRate(unsigned rate) const;
   unsigned defaultLayer() const;
   void setDefaultLayer(unsigned layer) const;
   unsigned defaultBitrate() const;
@@ -72,9 +71,17 @@ class RDLibraryConf
   void setRipperLevel(int level) const;
   QString cddbServer() const;
   void setCddbServer(QString server) const;
+  bool readIsrc() const;
+  void setReadIsrc(bool state) const;
   bool enableEditor() const;
   void setEnableEditor(bool state) const;
   void getSettings(RDSettings *s) const;
+  int srcConverter() const;
+  void setSrcConverter(int conv) const;
+  RDLibraryConf::SearchLimit limitSearch() const;
+  void setLimitSearch(RDLibraryConf::SearchLimit lmt) const;
+  bool searchLimited() const;
+  void setSearchLimited(bool state) const;
 
  private:
   void SetRow(const QString &param,int value) const;
