@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel_button.cpp,v 1.21 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdpanel_button.cpp,v 1.26.6.9 2014/02/06 20:43:47 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,19 +23,24 @@
 #include <rdconf.h>
 #include <rdpanel_button.h>
 
-#include <qbitmap.h>
+#include <qpixmap.h>
 #include <qpainter.h>
 
+#include <rdcartdrag.h>
 
-RDPanelButton::RDPanelButton(RDStation *station,bool flash,
+RDPanelButton::RDPanelButton(int row,int col,RDStation *station,bool flash,
 			     QWidget *parent,const char *name)
   : QPushButton(parent,name)
 {
+  button_row=row;
+  button_col=col;
   button_station=station;
   button_parent=parent;
-  button_default_palette=palette();
   button_flash=flash;
+  button_flash_state=false;
   button_hook_mode=false;
+  button_move_count=-1;
+  button_allow_drags=false;
   clear();
 }
 
@@ -57,6 +62,7 @@ void RDPanelButton::clear()
   button_length[1]=0;
   button_secs=-1;
   button_flashing=false;
+  button_flash_state=false;
   button_state=false;
   button_start_source=RDLogLine::StartUnknown;
   button_pause_when_finished=false;
@@ -73,7 +79,7 @@ QString RDPanelButton::text() const
 void RDPanelButton::setText(const QString &text)
 {
   button_text=text;
-  WriteKeycap();
+  WriteKeycap(-1);
 }
 
 
@@ -109,8 +115,13 @@ QColor RDPanelButton::defaultColor() const
 
 void RDPanelButton::setDefaultColor(QColor color)
 {
+  if(color==button_default_color) {
+    return;
+  }
   button_default_color=color;
-  button_default_palette=QPalette(color,button_parent->backgroundColor());
+  if(playDeck()==NULL) {
+    setColor(color);
+  }
 }
 
 
@@ -128,7 +139,9 @@ void RDPanelButton::setStartSource(RDLogLine::StartSource src)
 
 void RDPanelButton::setColor(QColor color)
 {
-  setPalette(QPalette(color,button_parent->backgroundColor()));
+  if(color==button_color) {
+    return;
+  }
   button_color=color;
   if(button_flash) {
     if(color==button_parent->backgroundColor()) {
@@ -138,6 +151,7 @@ void RDPanelButton::setColor(QColor color)
       button_flashing=true;
     }
   }
+  WriteKeycap(button_secs);
 }
 
 
@@ -243,7 +257,7 @@ void RDPanelButton::setActiveLength(int msecs)
   button_active_length=msecs;
   button_end_time=button_start_time.addMSecs(button_active_length);
   if((button_start_time.isNull())&&(button_cart!=0)) {
-    WriteKeycap();
+    WriteKeycap(-1);
   }
 }
 
@@ -260,7 +274,7 @@ void RDPanelButton::reset()
   button_end_time=QTime();
   setColor(button_default_color);
   if(button_cart!=0) {
-    WriteKeycap();
+    WriteKeycap(-1);
   }
   setDeck(-1);
   button_play_deck=NULL;
@@ -275,7 +289,19 @@ return button_pause_when_finished;
 
 void RDPanelButton::setPauseWhenFinished(bool pause_when_finished)
 {
-button_pause_when_finished=pause_when_finished;
+  button_pause_when_finished=pause_when_finished;
+}
+
+
+void RDPanelButton::resetCounter()
+{
+  WriteKeycap(-1);
+}
+
+
+void RDPanelButton::setAllowDrags(bool state)
+{
+  button_allow_drags=state;
 }
 
 
@@ -307,14 +333,12 @@ void RDPanelButton::tickClock()
 
 void RDPanelButton::flashButton(bool state)
 {
+  if(state==button_flash_state) {
+    return;
+  }
+  button_flash_state=state;
   if(button_flashing&&button_state) {
-    if(state) {
-      setPalette(QPalette(button_color,button_parent->backgroundColor()));
-    }
-    else {
-      setPalette(QPalette(button_parent->backgroundColor(),
-			  button_parent->backgroundColor()));
-    }
+    WriteKeycap(button_secs);
   }
 }
 
@@ -331,6 +355,143 @@ void RDPanelButton::keyReleaseEvent(QKeyEvent *e)
 }
 
 
+void RDPanelButton::mousePressEvent(QMouseEvent *e)
+{
+  button_move_count=10;
+  QPushButton::mousePressEvent(e);
+}
+
+
+void RDPanelButton::mouseMoveEvent(QMouseEvent *e)
+{
+  button_move_count--;
+  if(button_move_count==0) {
+    QPushButton::mouseReleaseEvent(e);
+    if(button_allow_drags) {
+      RDCartDrag *d=new RDCartDrag(button_cart,button_text,button_color,this);
+      d->dragCopy();
+    }
+  }
+}
+
+
+void RDPanelButton::mouseReleaseEvent(QMouseEvent *e)
+{
+  button_move_count=-1;
+  QPushButton::mouseReleaseEvent(e);
+}
+
+
+void RDPanelButton::dragEnterEvent(QDragEnterEvent *e)
+{
+  e->accept(RDCartDrag::canDecode(e)&&button_allow_drags&&
+  ((button_play_deck==NULL)||(button_play_deck->state()==RDPlayDeck::Stopped)));
+}
+
+
+void RDPanelButton::dropEvent(QDropEvent *e)
+{
+  unsigned cartnum;
+  QColor color;
+  QString title;
+
+  if(RDCartDrag::decode(e,&cartnum,&color,&title)) {
+    emit cartDropped(button_row,button_col,cartnum,color,title);
+  }
+}
+
+
+void RDPanelButton::WriteKeycap(int secs)
+{
+  QString text=button_text;
+  QPixmap *pix=new QPixmap(size().width(),size().height());
+  QPainter *p=new QPainter(pix);
+  if(button_state) {
+    if(button_flash) {
+      if(button_flash_state) {
+	p->fillRect(0,0,size().width(),size().height(),button_color);
+	p->setPen(RDGetTextColor(button_color));
+      }
+      else {
+	p->fillRect(0,0,size().width(),size().height(),button_default_color);
+	p->setPen(RDGetTextColor(button_default_color));
+      }
+    }
+    else {
+      p->fillRect(0,0,size().width(),size().height(),button_color);
+      p->setPen(RDGetTextColor(button_color));
+    }
+  }
+  else {
+    p->fillRect(0,0,size().width(),size().height(),button_color);
+    p->setPen(RDGetTextColor(button_color));
+  }
+
+  //
+  // Button Title
+  //
+  QFont font("helvetica",13,QFont::Normal);
+  font.setPixelSize(13);
+  QFontMetrics m(font);
+  p->setFont(font);
+  p->drawText(RDPANEL_BUTTON_MARGIN,m.lineSpacing(),
+	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
+  p->drawText(RDPANEL_BUTTON_MARGIN,2*m.lineSpacing(),
+	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
+  p->drawText(RDPANEL_BUTTON_MARGIN,3*m.lineSpacing(),
+	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
+
+  //
+  // Time Field & Output Text
+  //
+  if(!button_text.isEmpty()) {
+    if(secs<0) {
+      QFont out_font("helvetica",13,QFont::Normal);
+      out_font.setPixelSize(13);
+      p->setFont(out_font);
+      if(button_pause_when_finished) {
+        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,"Finished");
+        }
+      else {
+	if(button_active_length>=0) {
+	  p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-
+		      RDPANEL_BUTTON_MARGIN,
+		      RDGetTimeLength(button_active_length+1000,true,false));
+	}
+	else {
+	  p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-
+		      RDPANEL_BUTTON_MARGIN,tr("No Audio"));
+	}
+      }
+    }
+    else {
+      if(secs>8) {
+        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,
+		  RDGetTimeLength(1000*(secs+1),true,false));
+        }
+      else {
+        QFont out_font("helvetica",18,QFont::Bold);
+        out_font.setPixelSize(18);
+        p->setFont(out_font);
+        QString secstr=QString().sprintf(":%d",secs+1);
+        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,secstr);
+        }
+      QFont out_font("helvetica",18,QFont::Bold);
+      out_font.setPixelSize(18);
+      p->setFont(out_font);
+      QFontMetrics om(out_font);
+      p->drawText(size().width()-om.width(button_output_text)-
+		  RDPANEL_BUTTON_MARGIN,
+		  size().height()-RDPANEL_BUTTON_MARGIN,button_output_text);
+    }
+  }
+  p->end();
+  setPixmap(*pix);
+  delete p;
+  delete pix;
+}
+
+
 QString RDPanelButton::WrapText(QString text,int *lines)
 {
   QFontMetrics fm(font());
@@ -385,72 +546,6 @@ QString RDPanelButton::WrapText(QString text,int *lines)
 }
 
 
-void RDPanelButton::WriteKeycap(int secs)
-{
-  QString text=button_text;
-  QBitmap *pix=new QBitmap(size().width(),size().height());
-  QPainter *p=new QPainter(pix);
-  p->eraseRect(0,0,size().width(),size().height());
-  p->setPen(QColor(color1));
-
-  //
-  // Button Title
-  //
-  QFont font("helvetica",13,QFont::Normal);
-  font.setPixelSize(13);
-  QFontMetrics m(font);
-  p->setFont(font);
-  p->drawText(RDPANEL_BUTTON_MARGIN,m.lineSpacing(),
-	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
-  p->drawText(RDPANEL_BUTTON_MARGIN,2*m.lineSpacing(),
-	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
-  p->drawText(RDPANEL_BUTTON_MARGIN,3*m.lineSpacing(),
-	      GetNextLine(&text,m,size().width()-3*RDPANEL_BUTTON_MARGIN));
-
-  //
-  // Time Field & Output Text
-  //
-  if(!button_text.isEmpty()) {
-    if(secs<0) {
-      QFont out_font("helvetica",13,QFont::Normal);
-      out_font.setPixelSize(13);
-      p->setFont(out_font);
-      if(button_pause_when_finished) {
-        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,"Finished");
-        }
-      else {
-	      p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,
-			  RDGetTimeLength(button_active_length+1000,true,false));
-      }
-    }
-    else {
-      if(secs>8) {
-        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,
-		  RDGetTimeLength(1000*(secs+1),true,false));
-        }
-      else {
-        QFont out_font("helvetica",18,QFont::Bold);
-        out_font.setPixelSize(18);
-        p->setFont(out_font);
-        QString secstr=QString().sprintf(":%d",secs+1);
-        p->drawText(RDPANEL_BUTTON_MARGIN,size().height()-RDPANEL_BUTTON_MARGIN,secstr);
-        }
-      QFont out_font("helvetica",18,QFont::Bold);
-      out_font.setPixelSize(18);
-      p->setFont(out_font);
-      QFontMetrics om(out_font);
-      p->drawText(size().width()-om.width(button_output_text)-
-		  RDPANEL_BUTTON_MARGIN,
-		  size().height()-RDPANEL_BUTTON_MARGIN,button_output_text);
-    }
-  }
-  p->end();
-  setPixmap(*pix);
-  delete p;
-  delete pix;
-}
-
-
 QString RDPanelButton::GetNextLine(QString *str,const QFontMetrics &m,int len)
 {
   QString ret;
