@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Feed
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_feed.cpp,v 1.5.2.5 2009/05/26 18:33:30 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -77,7 +75,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   //
   // Channel Section
   //
-  feed_channel_section_label=new QLabel("CHANNEL VALUES",this);
+  feed_channel_section_label=new QLabel(tr("CHANNEL VALUES"),this);
   feed_channel_section_label->setGeometry(30,41,130,20);
   feed_channel_section_label->setAlignment(AlignCenter);
   feed_channel_section_label->setFont(font);
@@ -579,7 +577,7 @@ void EditFeed::setFormatData()
 {
   RDStation *station=new RDStation(admin_config->stationName());
   RDExportSettingsDialog *dialog=
-    new RDExportSettingsDialog(&feed_settings,station,this,"dialog");
+    new RDExportSettingsDialog(&feed_settings,station,this);
   dialog->exec();
   delete dialog;
   delete station;
