@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_casts.cpp,v 1.13.2.4 2009/05/21 17:32:17 cvs Exp $
+//      $Id: list_casts.cpp,v 1.18.4.1 2013/11/13 23:36:35 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -251,15 +251,17 @@ QSizePolicy ListCasts::sizePolicy() const
 void ListCasts::addCartData()
 {
   QString cutname;
-  RDCutDialog *cd=new RDCutDialog(&cutname,rdstation_conf,&cast_filter,
-				  &cast_group,cast_ripc->user());
+  RDCutDialog *cd=new RDCutDialog(&cutname,rdstation_conf,cast_system,
+				  &cast_filter,&cast_group,&cast_schedcode,
+				  cast_ripc->user());
   if(cd->exec()!=0) {
     delete cd;
     return;
   }
   delete cd;
   RDFeed::Error err;
-  unsigned cast_id=list_feed->postCut(cutname,&err);
+  unsigned cast_id=list_feed->postCut(cast_user,rdstation_conf,cutname,&err,
+				      config->logXloadDebugData(),config);
   if(err!=RDFeed::ErrorOk) {
     QMessageBox::warning(this,tr("Posting Error"),RDFeed::errorString(err));
     return;
@@ -282,7 +284,8 @@ void ListCasts::addFileData()
     return;
   }
   RDFeed::Error err;
-  unsigned cast_id=list_feed->postFile(srcfile,&err);
+  unsigned cast_id=list_feed->postFile(rdstation_conf,srcfile,&err,
+				       config->logXloadDebugData(),config);
   if(err!=RDFeed::ErrorOk) {
     QMessageBox::warning(this,tr("Posting Error"),RDFeed::errorString(err));
     return;
@@ -316,6 +319,7 @@ void ListCasts::deleteData()
 {
   QString sql;
   RDSqlQuery *q;
+  QString err_text;
 
   RDListViewItem *item=(RDListViewItem *)list_casts_view->selectedItem();
   if(item==NULL) {
@@ -337,19 +341,11 @@ void ListCasts::deleteData()
   sleep(1);
   qApp->processEvents();
   RDPodcast *cast=new RDPodcast(item->id());
-  QString cmd=cast->audioPurgeCommand();
-  if(cmd.isEmpty()) {
-    pd->reset();
-    QMessageBox::warning(this,tr("Internal Error"),
-			 tr("Unable to generate purge command!"));
-    delete pd;
-    delete cast;
-    return;
-  }
-  if(system(cmd)!=0) {
-    pd->reset();
+  if(!cast->removeAudio(list_feed,&err_text,config->logXloadDebugData())) {
     if(QMessageBox::warning(this,tr("Remote Error"),
-	      tr("Unable to delete remote audio!\nContinue deleting cast?"),
+			    tr("Unable to delete remote audio!\n")+
+			    tr("The server said: \"")+err_text+"\".\n\n"+
+			    tr("Continue deleting cast?"),
 		 QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
       delete pd;
       delete cast;
@@ -358,7 +354,6 @@ void ListCasts::deleteData()
   }
   pd->setProgress(1);
   qApp->processEvents();
-
   sql=QString().sprintf("delete from PODCASTS where ID=%u",item->id());
   q=new RDSqlQuery(sql);
   delete q;
@@ -499,13 +494,14 @@ void ListCasts::RefreshItem(RDListViewItem *item)
 	break;
     }
     item->setText(1,q->value(1).toString());
-    item->setText(2,q->value(2).toDateTime().toString("MM/dd/yyyy hh:mm:ss"));
+    item->setText(2,RDUtcToLocal(q->value(2).toDateTime()).
+		  toString("MM/dd/yyyy hh:mm:ss"));
     if(q->value(3).toInt()==0) {
       item->setText(3,tr("Never"));
     }
     else {
-      item->setText(3,q->value(2).toDateTime().addDays(q->value(3).toInt()).
-		    toString("MM/dd/yyyy"));
+      item->setText(3,RDUtcToLocal(q->value(2).toDateTime()).
+		    addDays(q->value(3).toInt()).toString("MM/dd/yyyy"));
     }
     item->setText(4,RDGetTimeLength(q->value(4).toInt(),false,false));
     item->setText(5,q->value(5).toString());
