@@ -1316,5 +1316,9 @@ ny</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
 </context>
 </TS>
