@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: audio_controls.h,v 1.4 2007/02/14 21:55:07 fredg Exp $
+//      $Id: audio_controls.h,v 1.6.8.1 2013/12/11 18:51:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,12 +26,17 @@
 #include <qcheckbox.h>
 #include <qdatetimeedit.h>
 #include <qlineedit.h>
+#include <qspinbox.h>
+
+#include <rdtimeedit.h>
 
 class AudioControls
 {
  public:
   QCheckBox *enforce_length_box;
-  QTimeEdit *forced_length_edit;
+  RDTimeEdit *forced_length_edit;
+  QLineEdit *song_id_edit;
+  QSpinBox *bpm_spin;
   QLineEdit *title_edit;
   QLineEdit *artist_edit;
   QLineEdit *album_edit;
@@ -40,6 +45,7 @@ class AudioControls
   QLineEdit *client_edit;
   QLineEdit *agency_edit;
   QLineEdit *publisher_edit;
+  QLineEdit *conductor_edit;
   QLineEdit *composer_edit;
   QLineEdit *user_defined_edit;
 };
