@@ -185,6 +185,10 @@ Wollen Sie sie speichern?</translation>
         <source>Remarks</source>
         <translation>Bemerkungen</translation>
     </message>
+    <message>
+        <source>&amp;Clone</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -506,7 +510,19 @@ Wollen Sie es überschreiben?</translation>
     </message>
     <message>
         <source>Len:</source>
-        <translation>Länge_</translation>
+        <translation>Länge:</translation>
+    </message>
+    <message>
+        <source>PRE-IMPORT CARTS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IMPORT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>and code</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -578,6 +594,23 @@ einem bereits existierendem Event.</translation>
     </message>
     <message>
         <source>Clear Hour</source>
+        <translation>Stunde löschen</translation>
+    </message>
+    <message>
+        <source>Change
+&amp;All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to update ALL clocks in the grid?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -675,6 +708,18 @@ Do you want to save?</source>
         <translation>Die Regeln wurden geändert.
 Wollen Sie sie speichern?</translation>
     </message>
+    <message>
+        <source>Scheduler Rules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist Separation:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import Rules from Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -1149,6 +1194,15 @@ Data</source>
         <source>RDLogManager - User: </source>
         <translation>RDLogManager - Benutzer: </translation>
     </message>
+    <message>
+        <source>RDLogEdit -- Database Skew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This version of RDLogManager is incompatible with the version installed on the server.
+See your system administrator for an update!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
@@ -1204,7 +1258,11 @@ Report</translation>
     </message>
     <message>
         <source>Report complete!</source>
-        <translation>Report komplett!</translation>
+        <translation type="obsolete">Report komplett!</translation>
+    </message>
+    <message>
+        <source>Report generated in</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1316,5 +1374,9 @@ Data</source>
         <source>Or after:</source>
         <translation>oder nach:</translation>
     </message>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
