@@ -49,6 +49,8 @@
 #include <local_gpio.h>
 #include <modemlines.h>
 #include <quartz1.h>
+#include <rossnkscp.h>
+#include <sas16000.h>
 #include <sas32000.h>
 #include <sas64000.h>
 #include <sas64000gpi.h>
@@ -163,6 +165,14 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new Quartz1(matrix,this);
     break;
 
+  case RDMatrix::RossNkScp:
+    ripcd_switcher[matrix_num]=new RossNkScp(matrix,this);
+    break;
+
+  case RDMatrix::Sas16000:
+    ripcd_switcher[matrix_num]=new Sas16000(matrix,this);
+    break;
+
   case RDMatrix::Sas32000:
     ripcd_switcher[matrix_num]=new Sas32000(matrix,this);
     break;
