@@ -1,10 +1,8 @@
 // sasusi.h
 //
-// A Rivendell switcher driver for the SAS User Serial Interface Protocol
+// A Rivendell switcher driver for the SAS USI Protocol
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: sasusi.h,v 1.8.2.1 2009/02/10 16:19:33 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,7 +21,8 @@
 #ifndef SASUSI_H
 #define SASUSI_H
 
-#include <qobject.h>
+#include <vector>
+
 #include <qsocket.h>
 #include <qhostaddress.h>
 #include <qtimer.h>
@@ -33,20 +32,23 @@
 #include <rdmacro.h>
 #include <rdtty.h>
 
+#include <switcher.h>
+
 #define SASUSI_RECONNECT_INTERVAL 10000
 #define SASUSI_MAX_LENGTH 256
 
-class SasUsi : public QObject
+class SasUsi : public Switcher
 {
  Q_OBJECT
  public:
   SasUsi(RDMatrix *matrix,QObject *parent=0,const char *name=0);
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
 
- signals:
-  void rmlEcho(RDMacro *cmd);
-  void gpoChanged(int matrix,int line,bool state);
-
  private slots:
   void ipConnect();
   void connectedData();
@@ -58,6 +60,7 @@ class SasUsi : public QObject
   void SendCommand(char *str);
   void DispatchCommand();
   void ExecuteMacroCart(unsigned cartnum);
+  QString PrettifyCommand(const char *cmd) const;
   RDTTYDevice *sas_device;
   QSocket *sas_socket;
   char sas_buffer[SASUSI_MAX_LENGTH];
@@ -73,6 +76,9 @@ class SasUsi : public QObject
   unsigned sas_start_cart;
   unsigned sas_stop_cart;
   RDMatrix::PortType sas_porttype;
+  std::vector<int> sas_console_numbers;
+  std::vector<int> sas_source_numbers;
+  std::vector<int> sas_relay_numbers;
 };
 
 
